@@ -1,7 +1,8 @@
+from .constraint import to_constraint, Constraint, NodeConstraint, ValueConstraint, cleaf, vval, vcheck, nval, ncheck
 from .flatten import flatten, unflatten, flatten_values, flatten_keys
 from .functional import mapping, filter_, mask, reduce_
 from .graph import graphics
 from .io import loads, load, dumps, dump
 from .service import jsonify, clone, typetrans, walk
 from .structural import subside, union, rise
-from .tree import TreeValue, delayed
+from .tree import TreeValue, delayed, ValidationError
